@@ -28,7 +28,7 @@ def run_inference(cov_df, lineages, k_interval=[10,30], n_runs=2, steps=500,
             x_k = single_run(k=k, df=cov_df, lineages=lineages, run=run, 
                 steps=steps, covariance=covariance, lr=lr, p=p, 
                 hyperparameters=hyperparameters, convergence=convergence, 
-                show_progr=show_progr, random_state=random_state)
+                show_progr=show_progr, store_params=store_params, random_state=random_state)
 
             kk = x_k.params["K"]
 
@@ -42,7 +42,8 @@ def run_inference(cov_df, lineages, k_interval=[10,30], n_runs=2, steps=500,
 
 
 def single_run(k, df, lineages, run="", steps=500, covariance="diag", lr=0.001,
-    p=0.01, convergence=True, show_progr=True, random_state=25, hyperparameters=dict()):
+    p=0.01, convergence=True, show_progr=True, random_state=25, 
+    hyperparameters=dict(), store_params=False):
 
     pyro.clear_param_store()
     try:
@@ -56,7 +57,9 @@ def single_run(k, df, lineages, run="", steps=500, covariance="diag", lr=0.001,
     for name, value in hyperparameters.items():
         x.set_hyperparameters(name, value)
     
-    x.fit(steps=steps, cov_type=covariance, lr=lr, p=p, convergence=convergence, random_state=random_state, show_progr=show_progr)
+    x.fit(steps=steps, cov_type=covariance, lr=lr, p=p,
+        convergence=convergence, random_state=random_state, 
+        show_progr=show_progr, store_params=store_params)
     x.classifier()
 
     return x
